summaryrefslogtreecommitdiffstats
path: root/kig/misc/kiginputdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/kiginputdialog.h')
-rw-r--r--kig/misc/kiginputdialog.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kig/misc/kiginputdialog.h b/kig/misc/kiginputdialog.h
index c7b29e73..60f2ba54 100644
--- a/kig/misc/kiginputdialog.h
+++ b/kig/misc/kiginputdialog.h
@@ -41,13 +41,14 @@ class KigInputDialog
: KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
private:
- KigInputDialog( const TQString& caption, const TQString& label, TQWidget* parent,
+ KigInputDialog( const TQString& caption, const TQString& label, TQWidget* tqparent,
const KigDocument& doc, Coordinate* c1, Coordinate* c2 );
- KigInputDialog( TQWidget* parent, const Goniometry& g );
+ KigInputDialog( TQWidget* tqparent, const Goniometry& g );
virtual void keyPressEvent( TQKeyEvent* e );
@@ -69,7 +70,7 @@ public:
*
* \param caption caption of the dialog
* \param label text of the label of the dialog
* \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted Coordinate
* \param doc the actual Kig document
@@ -79,14 +80,14 @@ public:
* displayed as initial value of the correspondenting text edit
*/
static void getCoordinate( const TQString& caption, const TQString& label,
- TQWidget* parent, bool* ok, const KigDocument& doc, Coordinate* cvalue );
+ TQWidget* tqparent, bool* ok, const KigDocument& doc, Coordinate* cvalue );
/**
* Static convenience function to get two Coordinates at once from the user.
*
* \param caption caption of the dialog
* \param label text of the label of the dialog
* \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting
* well-formatted Coordinates
* \param doc the actual Kig document
@@ -102,14 +103,14 @@ public:
* the text edit representing the second Coordinate.
*/
static void getTwoCoordinates( const TQString& caption, const TQString& label,
- TQWidget* parent, bool* ok, const KigDocument& doc, Coordinate* cvalue,
+ TQWidget* tqparent, bool* ok, const KigDocument& doc, Coordinate* cvalue,
Coordinate* cvalue2 );
/**
* Static convenience function to get an angle incapsulated in a Goniometry
* class.
*
* \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted angle
* \param g the Goniometry class containing the original angle we are going
@@ -117,7 +118,7 @@ public:
*
* \return a Goniometry class containing the new angle
*/
- static Goniometry getAngle( TQWidget* parent, bool* ok, const Goniometry& g );
+ static Goniometry getAngle( TQWidget* tqparent, bool* ok, const Goniometry& g );
};
#endif
@@ -69,7 +70,7 @@ public:
* \param caption caption of the dialog
* \param label text of the label of the dialog
- * \param parent parent of the dialog widget
+ * \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted Coordinate
@@ -79,14 +80,14 @@ public:
* \param caption caption of the dialog
* \param label text of the label of the dialog
- * \param parent parent of the dialog widget
+ * \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting
* well-formatted Coordinates
@@ -102,14 +103,14 @@ public:
* class.
*
- * \param parent parent of the dialog widget
+ * \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted angle